package activation

import "github.com/opencontainers/runc/internal/third_party/systemd/activation"

Package activation implements primitives for systemd socket activation.

It is a partial copy of https://github.com/coreos/go-systemd/v22/activation (https://github.com/coreos/go-systemd/blob/ce60782c0aabb616faa8e60f91e639d91f631e99/activation/files_unix.go), to avoid bringing in crypto/tls dependency.

Index

Functions

func Files

func Files() []*os.File

Files returns a slice containing a os.File object for each file descriptor passed to this process via systemd fd-passing protocol.

The order of the file descriptors is preserved in the returned slice.

Source Files

files_unix.go

Version
v1.5.0-rc.1
Published
Mar 13, 2026
Platform
linux/amd64
Imports
4 packages
Last checked
28 minutes ago

Tools for package owners.