package apparmor
import "github.com/opencontainers/runc/libcontainer/apparmor"
Index ¶
Variables ¶
ErrApparmorNotEnabled indicates that AppArmor is not enabled or not supported.
Functions ¶
func ApplyProfile ¶
ApplyProfile will apply the profile with the specified name to the process after the next exec. It is only supported on Linux and produces an ErrApparmorNotEnabled on other platforms.
func IsEnabled ¶
func IsEnabled() bool
IsEnabled returns true if apparmor is enabled for the host.
Source Files ¶
- Version
- v1.4.0-rc.1
- Published
- Sep 5, 2025
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 6 seconds ago –
Tools for package owners.